<?
/*                  D A T A - E D I T   F U N C T I O N S                     */

/*******************************************************************************
* Function: edit_user(...)                                                     *
* Updates the user table with the new content of the parameters                *
*******************************************************************************/
function edit_user ($uid, $passwd1, $passwd2, $realname, $email, $homepage,
					$icq_num, $phone_num, $birthday, $occupation, $interests,
					$residence, $signature, $subtitle, $photo_url, $avatar_url,
					$language, $theme, $show_days, $email_visible, $admin_mail,
					$avatar_enable, $status, $new_username) {
	
	global $logged_in, $user_prefs, $gpb_username, $gpb_password, $pwd_min_length, $pwd_max_length;
	
	// We start with some tests. If all tests succeed, we change the user
	// properties in the databse and return a "0". If there where any errors we
	// return a non-zero value indicating what's wrong. These non-zero values are:
	// 1: user is not logged in
	// 2: passwd1 and passwd2 are not identical
	// 3: passwd too short
	// 4: passwd too long
	// 5: invalid emailaddress
	// 6: emailaddress already in use
	// 9: unknown database error
	
	$passwd1 = trim($passwd1);
	$passwd2 = trim($passwd2);
	
	// Check if the username/password combo is right
	if ($logged_in != 1) {
		return 1;
	}
	
	// Get properties of the user which performs this operation
	$user_uid = username_to_uid($gpb_username);
	
	// We need to check if the username and uid are form the same record
	if ($user_uid != $uid) {
		// Well, the username could be an administrator trying to edit the record
		if ($user_prefs->status != _ADMINISTRATOR_) {
			return 1;
		}
	}
	
	// No passwords were filled in
	if (($passwd1 != "") && ($passwd2 != "")) {
		// Check if passwd1 and new_passwd2 are identical
		if ($passwd1 != $passwd2) {
			return 2;
		}
		
		// Check if the new password is too short
		if (strlen ($passwd1) < $pwd_min_length) {
			return 3;
		}
		
		// Check if the new password is too long
		if (strlen ($passwd1) > $pwd_max_length) {
			return 4;
		}
		
		// New password is okay, let's encrypt it
		$md5passwd = md5($passwd1);
	}
	
	// Check if emailaddress is valid
	if (!valid_email ($email)) {
		return 5;
	}
	
	// Check if email already exists
	gpb_connect ();
	$query = "SELECT uid FROM gpb_user WHERE email='$email'";
	$result = mysql_query ($query);
	gpb_close ();
	if ($result) {
		while ($row = mysql_fetch_array($result)) {
			if ($row['uid'] != $uid) {
				return 6;
			}
		}
	}
	
	// OK, we're ready to modify the record, connect to the database and construct the query
	gpb_connect ();
	
	// Query begin
	$query = "UPDATE gpb_user SET ";
	
	// If the md5password field is empty, we just don't update the password
	if ($md5passwd != "") {
		$query .= "md5passwd='$md5passwd', ";
	}
	
	// Default updates...
	$query .=  "realname='$realname', email='$email', homepage='$homepage', icq_num='$icq_num', 
				phone_num='$phone_num', birthday='$birthday', occupation='$occupation',
				interests='$interests', residence='$residence', signature='$signature', 
				subtitle='$subtitle', photo_url='$photo_url', avatar_url='$avatar_url',
				language='$language', theme='$theme', show_days='$show_days',
				email_visible='$email_visible', admin_mail='$admin_mail',
				avatar_enable='$avatar_enable'";
	
	// Admins may want to edit the user status
	if (($user_prefs->status == _ADMINISTRATOR_) && ($status != "")) {
		$query .= ", status='$status'";
	}
	// Admins may want to edit the username
	if (($user_prefs->status == _ADMINISTRATOR_) && ($new_username != "")) {
		$query .= ", username='$new_username'";
	}
	
	// Query end
	$query .= " WHERE gpb_user.uid = $uid";
	
	// Exec the query and close the database
	$result = mysql_query ($query);
	gpb_close();
	
	// Updates failed -> unknown database error
	if (!$result) {
		return 9;
	}
	
	return 0;
}


/*******************************************************************************
* Function: edit_category(...)                                                 *
* Updates the category table with the new content of the parameters            *
*******************************************************************************/
function edit_category($cid, $ctitle, $pos) {
	
	global $logged_in, $user_prefs, $gpb_username, $gpb_password;
	
	// We start with some tests. If all tests succeed, we change the category
	// properties in the database and return a "0". If there where any errors
	// we return a non-zero value indicating what's wrong. These non-zero
	// values are:
	// 1: user not logged in
	// 2: user has not enough rights to edit a category
	// 3: no ctitle given
	// 4: no cid given
	// 5: invalid cid given
	// 9: unknown database error
	
	$ctitle = trim($ctitle);
	
	// Check if the user is logged in
	if ($logged_in != 1) {
		return 1;
	}
	
	// Check if the user has enough rights, eg: must be admin (level 3)
	if ($user_prefs->status != _ADMINISTRATOR_) {
		return 2;
	}
	
	// Check if there is a ctitle given
	if ($ctitle == "") {
		return 3;
	}
	
	// Check if there is a cid given
	if ($cid == "") {
		return 4;
	}
	
	// Check if the cid is valid
	gpb_connect ();
	$query = "SELECT cid FROM gpb_cat WHERE cid = $cid";
	$result = mysql_query ($query);
	gpb_close ();
	if (!$result) {
		return 5;
	}
	
	// Everything should be fine now, so let's edit the category
	gpb_connect ();
	$query = "UPDATE gpb_cat SET ctitle='$ctitle', pos='$pos' WHERE cid='$cid';";
	$result = mysql_query ($query);
	gpb_close ();
	if (!$result) {
		return 9;
	}
	
	return 0;
}


/*******************************************************************************
* Function: edit_subcategory(...)                                              *
* Updates the subcategory table with the new content of the parameters         *
*******************************************************************************/
function edit_subcategory($sid, $cid, $stitle, $description, $abbrev, $mod_uid, $mod_only, $pos) {
	
	global $logged_in, $user_prefs, $gpb_username, $gpb_password;
	
	// We start with some tests. If all tests succeed, we change the subcategory
	// properties in the database and return a "0". If there where any errors
	// we return a non-zero value indicating what's wrong. These non-zero
	// values are:
	// 1: user not logged in
	// 2: user has not enough rights to edit a subcategory
	// 3: no stitle given
	// 4: no/invalid sid given
	// 5: no/invalig cid given
	// 6: no/invalid description given
	// 7: no/invalig mod_uid given
	// 8: no/invalig pos given
	// 9: unknown database error
	
	$stitle = trim($stitle);
	$description = trim($description);
	$abbrev = trim($abbrev);
	
	// Check if the user is logged in
	if ($logged_in != 1) {
		return 1;
	}
	
	// Check if the user has enough rights, eg: must be admin (level 3)
	if ($user_prefs->status != _ADMINISTRATOR_) {
		return 2;
	}
	
	// Check if there is a stitle given
	if ($stitle == "") {
		return 3;
	}
	
	// Check if there is a sid given
	if ($sid == "") {
		return 4;
	}
	
	// Check if the sid is valid
	gpb_connect ();
	$query = "SELECT sid FROM gpb_subcat WHERE sid=$sid";
	$result = mysql_query ($query);
	gpb_close();
	if (!$result) {
		return 4;
	}
	
	// Check if there is a cid given
	if ($cid == "") {
		return 5;
	}
	
	// Check if the cid is valid
	gpb_connect ();
	$query = "SELECT cid FROM gpb_cat WHERE cid=$cid";
	$result = mysql_query ($query);
	gpb_close();
	if (!$result) {
		return 5;
	}
	
	// Check if a valid description is given
	if ($description == "") {
		return 6;
	}
	
	gpb_connect ();
	$query = "SELECT uid FROM gpb_user WHERE uid=$mod_uid";
	$result = mysql_query ($query);
	gpb_close();
	if (!$result) {
		return 7;
	}
	
	if ($pos == "") {
		return 8;
	}
	
	// Everything should be fine now, so let's edit the category
	gpb_connect ();
	$query = "UPDATE gpb_subcat SET cid='$cid', stitle='$stitle', description='$description', abbrev='$abbrev', moderator_uid='$mod_uid', moderator_only='$mod_only', pos='$pos' WHERE sid='$sid';";
	$result = mysql_query ($query);
	gpb_close();
	if (!$result) {
		return 9;
	}
	
	return 0;
}


/*******************************************************************************
* Function: edit_topic(...)                                                    *
* Updates the topic table with the new content of the parameters               *
*******************************************************************************/
function edit_topic($username, $password, $tid, $sid, $ttitle, $icon, $mail_on_reply, $closed) {
	
	global $ttitle_min_length;
	
	// We start with some tests. If all tests succeed, we change the topic
	// properties in the database and return a "0". If there where any errors
	// we return a non-zero value indicating what's wrong. These non-zero
	// values are:
	// 1: user not logged in
	// 2: user has not enough rights to edit the topic
	// 3: no or invalid ttitle given
	// 4: no or invalid tid given
	// 5: no or invalid sid given
	// 9: unknown database error
	
	$ttitle = trim ($ttitle);
	
	// Check if the user is valid
	$legal = user_check($username, $password);
	if ($legal != 0) {
		return 1;
	}
	
	// Check if the user has enough rights: must be _at least_ moderator
	$uprefs = user_prefs($username);
	if ($uprefs < _MODERATOR_) {
		return 2;
	}
	
	// Check if there is a valid ttitle given
	if (strlen ($ttitle) < $ttitle_min_length) {
		return 3;
	}
	
	// Check if there is a tid given
	if ($tid == "") {
		return 4;
	}
	
	// Check if there is a valid tid given
	gpb_connect();
	$query = "SELECT last_pid, sid FROM gpb_topic WHERE tid='$tid';";
	$result = mysql_query($query);
	gpb_close();
	if ($result) {
		while ($row = mysql_fetch_array($result)) {
			$topic_last_pid = $row['last_pid'];
			$old_sid = $row['sid'];
		}
	}
	else {
		return 4;
	}
	
	// Check if there is a sid given
	if ($sid == "") {
		return 5;
	}
	
	// Check if there is a valid sid given
	gpb_connect();
	$query = "SELECT sid FROM gpb_subcat WHERE sid=$sid";
	$result = mysql_query($query);
	gpb_close();
	if (!$result) {
		return 5;
	}
	
	// Check if there is a valid sid given
	gpb_connect();
	$query = "SELECT last_pid FROM gpb_subcat WHERE sid=$old_sid";
	$result = mysql_query($query);
	gpb_close();
	if ($result) {
		while ($row = mysql_fetch_array($result)) {
			$subcat_last_pid = $row['last_pid'];
		}
	}
	
	// If there is no icon given use default icon "1"
	if ($icon == "") {
		$icon = 1;
	}
	
	// Everything should be okay now, so let's update the topic.
	gpb_connect ();
	$query = "UPDATE gpb_topic SET sid='$sid', ttitle='$ttitle', icon='$icon', mail_on_reply='$mail_on_reply', closed='$closed'
			  WHERE tid=$tid;";
	$result = mysql_query($query);
	gpb_close ();
	if (!$result) {
		return 9;
	}
	
	// If sid for the topic is changed we have to update the gpb_subcat table
	if ($sid != $old_sid) {
		
		// Get data of both subcats
		$old_subcat = info_by_sid ($old_sid);
		$new_subcat = info_by_sid ($sid);
		
		// Get all data of current topic
		$this_topic = info_by_tid ($tid);
		$num_posts = $this_topic->num_posts;
		
		gpb_connect();
		
		// Update the old subcategory
		$query = "UPDATE gpb_subcat SET num_topics=num_topics-1, num_posts=num_posts-'$num_posts' WHERE sid=$old_sid";
		mysql_query ($query);
		
		// Update the new subcategory
		$query = "UPDATE gpb_subcat SET num_topics=num_topics+1, num_posts=num_posts+'$num_posts' WHERE sid=$sid";
		mysql_query ($query);
		
		// It is possible that the last_pid for the subcat is changed, so update the last_pid fields
		if ($subcat_last_pid == $topic_last_pid) {
			
			// Select last_pid of the old topic
			$query = "SELECT gpb_post.pid FROM gpb_post, gpb_topic
					  WHERE gpb_topic.tid = gpb_post.tid 
						AND gpb_topic.sid = $old_sid 
					  ORDER BY gpb_post.timestamp DESC LIMIT 1;";
			$result = mysql_query ($query);
			$old_subcat_last_pid = 0;
			if ($result) {
				while ($row = mysql_fetch_array ($result)) {
					$old_subcat_last_pid = $row['pid'];
				}
			}
			
			// Update the new subcategory
			$query = "UPDATE gpb_subcat SET last_pid=$topic_last_pid WHERE sid=$sid;";
			mysql_query ($query);
			
			// Update the old subcategory
			$query = "UPDATE gpb_subcat SET last_pid=$old_subcat_last_pid WHERE sid=$old_sid";
			mysql_query ($query);
		}
		
		gpb_close();
	}
	
	return 0;
}


/*******************************************************************************
* Function: edit_post(...)                                                     *
* Updates the post table with the new content of the parameters                *
*******************************************************************************/
function edit_post($username, $password, $pid, $text, $icon, $enable_smilies) {
	
	// We start with some tests. If all tests succeed, we change the post
	// properties in the database and return a "0". If there where any errors
	// we return a non-zero value indicating what's wrong. These non-zero
	// values are:
	// 1: user not logged in
	// 2: user has not enough rights to edit the topic (must be owner od status => moderator)
	// 3: no or invalid text given
	// 4: no or invalid pid given
	// 9: unknown database error
	
	$text = trim($text);
	
	// Check if the user is logged in
	$legal = user_check($username, $password);
	if ($legal != 0) {
		return 1;
	}
	
	// Get data of the current post
	$this_post = info_by_pid ($pid);
	
	// Get uid of the username
	$uid = username_to_uid ($username);
	
	// Check if the user has enough rights, must be moderator or owner of the post
	$this_user = info_by_uid ($uid);
	if (($this_user->status > _MEMBER_) || ($this_post->uid == $uid)) {
		// noting
	}
	else {
		return 2;
	}
	
	// Check if there is a valid text given
	if ($text == "") {
		return 3;
	}
	
	// Check if there is a pid given
	if ($pid == "") {
		return 4;
	}
	
	// Check if given pid is valid
	gpb_connect ();
	$query = "SELECT pid FROM gpb_post WHERE pid = '$pid';";
	$result = mysql_query ($query);
	gpb_close();
	if (!$result) {
		return 4;
	}
	
	// If there is no icon given, we use icon "1"
	if (empty ($icon)) {
		$icon = 1;
	}
	
	gpb_connect ();
	$query = "UPDATE gpb_post SET text='$text', icon=$icon, enable_smilies=$enable_smilies WHERE pid=$pid";
	$result = mysql_query($query);
	gpb_close();
	if (!$result) {
		return 9;
	}
	
	return 0;
}

?>