<?
/*****************************************************************************
* Implementation of the GPB functions without database-interaction           *
* ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^           *
* This is one of the key files in GPB. It defines and implement all the      *
* database independant functions of GPB                                      *
*****************************************************************************/


/*****************************************************************************
* Function: list_themes ()                                                   *
* Returns an array with names of all available themes                        *
* Element 1 is the first theme                                               *
*****************************************************************************/
function list_themes () {
	global $root_path;
	$themesdir = dir ("$root_path/themes");
	$i = 1;
	while ($entry = $themesdir->read ()) {
		if ($entry != "." && $entry != "..") {
			$themes[$i] = $entry;
			$i++;
		}
	}
	return $themes;
}


/*****************************************************************************
* Function: list_languages ()                                                *
* Returns an array with abbreviations of all available languages             *
* Element 1 is the first language                                            *
*****************************************************************************/
function list_languages () {
	global $root_path;
	$langdir = dir ("$root_path/include/i18n");
	$i = 1;
	while ($entry = $langdir->read ()) {
		if ($entry != "." && $entry != "..") {
			$languages[$i] = substr ($entry, 0, 2);
			$i++;
		}
	}
	return $languages;
}

/*****************************************************************************
* Function: list_dbtypes ()                                                  *
* Returns an array with the names of all available databases                 *
* Element 1 is the first database                                            *
*****************************************************************************/
function list_dbtypes () {
	global $root_path;
	$dbdir = dir ("$root_path/include/");
	$i = 1;
	while ($entry = $dbdir->read ()) {
		if (($entry != ".") && ($entry != "..") && (substr($entry, 0, 2) == "db")) {
			$filelen = strlen ($entry);
			$dbtypes[$i] = substr ($entry, 3, $filelen - 11);
			$i++;
		}
	}
	return $dbtypes;
}

/*****************************************************************************
* Function: calc_pagecount($number, $entries_pp)                             *
* Return the number of pages                                                 *
*****************************************************************************/
function calc_pagecount($number, $entries_pp) {
	$pagecount = $number / $entries_pp;
	if (($number % $entries_pp) > 0) {
		$pagecount++;
	}
	$pagecount = (int)$pagecount;
	return $pagecount;
}

/*******************************************************************************
* Function: valid_passwd ($passwd1, $passwd2)                                  *
* Checks if $passwd1 and $passwd are identic and satisfy the norm              *
*******************************************************************************/
function valid_passwd ($passwd1, $passwd2) {
	
	global $pwd_min_length, $pwd_max_length;
	
	// return values:
	// 0: check succesful
	// 3: password 1 and password 2 are not identical
	// 4: password too short
	// 5: password too long
	
	// passwd1 and passwd2 identic?
	if ($passwd1 != $passwd2) {
		return 3;
	}
    // passwd too short?
	if (strlen($passwd1) < $pwd_min_length) {
		return 4;
	}
	// passwd too long?
	if (strlen($passwd1) > $pwd_max_length) {
		return 5;
	}
	
    return 0;
}

/*******************************************************************************
* Function: valid_email ($email)                                               *
* Returns '1' if emailaddress $email is valid, else '0'                        *
*******************************************************************************/
function valid_email ($email) {
	
	// Check if email address contain illegal charcters
	$ill_chars = '<>/';
	for ($i = 0; $i < strlen($ill_chars); $i++) {
		for ($j = 0; $j < strlen($email); $j++) {
			if (substr ($ill_chars, $i, 1) == substr ($email, $j, 1)) {
				return 0;
			}
		}
	}
	
	if (ereg("(([a-z0-9_]|\\-|\\.)+@([^[:space:]]*)([[:alnum:]-])\.([^[:space:]]*)([[:alnum:]-]))", $email) == 0) {
		return 0;
	}
	return 1;
}



/*                  H T M L  -  P A R S E   F U N C T I O N S                 */

/*******************************************************************************
* Function: get_first_chars ($text)                                            *
* Returns only the first chars from a post and disables all ubbcode and        *
* smilies. (especialy voor list the last post in 'today')                      *
*******************************************************************************/
function get_first_chars ($text) {
	$shorttext = substr ($text, 0, 255);
	if (strlen ($text) > 255) {
		$shorttext .= "[...]";
	}
	return $shorttext;
}


/*******************************************************************************
* Function: parse_dehtml ($text)                                               *
* Converts raw userinput to unHTMLlizid data                                   *
*******************************************************************************/
function parse_dehtml ($text) {
	$newtext = htmlspecialchars ($text);
	return $newtext;
}


/*******************************************************************************
* Function: QuoteLimit ($text)                                                 *
* Limits the number of quotes.                                                 *
*******************************************************************************/
function parse_quotelimit ($text) {
	
	// this function does
	return $text;
	
}


/*******************************************************************************
* Function: parse_remove_ubbcode ($text)                                       *
* Returns the text, but without any UBB code                                   *
*******************************************************************************/
function parse_remove_ubbcode ($text) {
	$text = eregi_replace ('\[b\]', '', $text);
	$text = eregi_replace ('\[/b\]', '', $text);
	$text = eregi_replace ('\[i\]', '', $text);
	$text = eregi_replace ('\[/i\]', '', $text);
	$text = eregi_replace ('\[code\]', '', $text);
	$text = eregi_replace ('\[/code\]', '', $text);
	$text = eregi_replace ('\[list\]', '', $text);
	$text = eregi_replace ('\[/list\]', '', $text);
	$text = eregi_replace ('\[\*\]', '', $text);
	$text = eregi_replace ('\[quote\]', '', $text);
	$text = eregi_replace ('\[/quote\]', '', $text);
	
	$text = preg_replace ("/(\[img\]|\[IMG\])(\S+?)(\[\/img\]|\[\/IMG\])/", "[IMAGE]", $text);
	$text = preg_replace ("/(\[edit\]|\[EDIT\])(.+?)(\[\/edit\]|\[\/EDIT\])/", "\\2", $text);
	$text = preg_replace ("/(\[url=|\[URL=)(\S+?)(\])(.+?)(\[\/url\]|\[\/URL\])/", "\\4", $text);
	return $text;
}

/*******************************************************************************
* Function: parse_makeurl ($text)                                              *
* Converts all plain URL's in a raw tekst into hyperlinks                      *
*******************************************************************************/
function parse_makeurl ($text) {
	
	// converts url to hyperlinks
	$text = ereg_replace ("[A-Za-z]+://[^<>\n]*[A-Za-z0-9/]", '<A HREF="\\0">\\0</A>', $text);
	// converts emailaddress automaticaly to hyperlink (including a "mailto:")
	$text = ereg_replace ('[A-Za-z0-9]([A-Za-z0-9._]*[A-Za-z0-9]|())@[A-Za-z0-9]([A-Za-z0-9.\-]*[A-Za-z0-9]|())\.[A-Za-z]+', '<A HREF="mailto:\\0">\\0</A>', $text);
	
	return $text;
}


/*******************************************************************************
* Function: parse_ubbcodetohtml ($text)                                        *
* Does some extra things with the text, like changing linebreaks to <BR>.      *
* It also handles the UBB code.                                                *
*******************************************************************************/
function parse_ubbcodetohtml ($text) {
	
	// replace linebreaks by "<BR>" (HTML newline)
	$text = nl2br($text);
	
	// process UBB code
	$text = eregi_replace ('\[b\]', '<B>', $text);
	$text = eregi_replace ('\[/b\]', '</B>', $text);
	$text = eregi_replace ('\[i\]', '<I>', $text);
	$text = eregi_replace ('\[/i\]', '</I>', $text);
	$text = eregi_replace ('\[code\]', '<PRE>', $text);
	$text = eregi_replace ('\[/code\]', '</PRE>', $text);
	$text = eregi_replace ('\[list\]', '<UL>', $text);
	$text = eregi_replace ('\[/list\]', '</UL>', $text);
	$text = eregi_replace ('\[quote\]', '<BLOCKQUOTE><DIV CLASS="junk">Quote:</DIV><HR>', $text);
	$text = eregi_replace ('\[/quote\]', '<HR></BLOCKQUOTE>', $text);
	$text = ereg_replace ('\[\*\]', '<LI>', $text);
	
	$text = preg_replace ("/(\[img\]|\[IMG\])(\S+?)(\[\/img\]|\[\/IMG\])/", "<IMG SRC=\"\\2\">", $text);
	$text = preg_replace ("/(\[edit\]|\[EDIT\])(.+?)(\[\/edit\]|\[\/EDIT\])/", "<P CLASS=\"junk\">\\2</P>", $text);
	$text = preg_replace ("/(\[url=|\[URL=)(\S+?)(\])(.+?)(\[\/url\]|\[\/URL\])/", "<A HREF=\"\\2\">\\4</A>", $text);
	
	return $text;
}


/*******************************************************************************
* Function: parse_smilies ($text)                                              *
* Converts all emoticons in raw text into links to graphical replacements      *
*******************************************************************************/
function parse_smilies ($text) {
    global $theme;
    $text = ereg_replace (':)', "<IMG SRC=\"$theme/images/smilies/smile.gif\" ALT=\":)\" BORDER=\"0\">", $text);
    $text = ereg_replace (':\(',"<IMG SRC=\"$theme/images/smilies/frown.gif\" ALT=\":(\" BORDER=\"0\">", $text);
    $text = ereg_replace (';)', "<IMG SRC=\"$theme/images/smilies/wink.gif\" ALT=\";)\" BORDER=\"0\">", $text);
    $text = ereg_replace (':p', "<IMG SRC=\"$theme/images/smilies/tongue.gif\" ALT=\":p\" BORDER=\"0\">", $text);
    $text = ereg_replace (':}', "<IMG SRC=\"$theme/images/smilies/redface.gif\" ALT=\":}\" BORDER=\"0\">", $text);
    $text = ereg_replace (':D', "<IMG SRC=\"$theme/images/smilies/biggrin.gif\" ALT=\":D\" BORDER=\"0\">", $text);
    $text = ereg_replace (':\?',"<IMG SRC=\"$theme/images/smilies/confused.gif\" ALT=\":?\" BORDER=\"0\">", $text);
    $text = ereg_replace ('8)', "<IMG SRC=\"$theme/images/smilies/cool.gif\" ALT=\"8)\" BORDER=\"0\">", $text);
    $text = ereg_replace (':o', "<IMG SRC=\"$theme/images/smilies/eek.gif\" ALT=\":o\" BORDER=\"0\">", $text);
    $text = ereg_replace (':#', "<IMG SRC=\"$theme/images/smilies/mad.gif\" ALT=\":#\" BORDER=\"0\">", $text);
    $text = ereg_replace (':@', "<IMG SRC=\"$theme/images/smilies/rolleyes.gif\" ALT=\":@\" BORDER=\"0\">", $text);
    return $text;
}
?>
